@@ -4,10 +4,9 @@
 #' @param X A data frame with the predictor variables.
 
 normal.estimation <- function(X){
-  mu <- apply(X, 2, mean)
-  sd <- apply(X, 2, sd)
-  U <- t(apply(X, 1, function(x) pnorm(x,mu,sd)))
-  value <- list(mu = mu,sd = sd,U = U)
+  mu <- mean(X)
+  sd <- sd(X)
+  value <- list(mu = mu,sd = sd, den = "normal")
   return(value)
 }
 
